# Copyright (C) 2010 Alejandro Ochoa, Singh Research Group, Princeton University
# This file is part of dPUC.
# dPUC is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
# dPUC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with dPUC.  If not, see <http://www.gnu.org/licenses/>.

use lib '.';
use General;
use FilePaths;
use Hits;
use strict;

# this script reads the prot2hits (parsed from Pfam-A.full) and generates a list of exact architectures and instances.
# an architecture is defined here as an ordered list of domains, so two architectures are the same iff they have identical ordered lists of accessions.

# constants
my $comp = 'gzip'; # compress output

# this structure counts the number of times we see an architecture
# for convenience architectures are textified (they are used as hash keys), separated by dashes (-), but to save memory the PF prefixes are erased (in this case we know they're all Pfam anyway)
my %arch2c;

# we don't expect the entire prot2hits structure to fit in memory, so we'll read it on the fly (prot-by-prot)
my ($fhi, $header, $protNext) = Hits::readHitsManyProts_OnTheFly_StartHeader($FilePaths::pfamProt2hits);
while ($protNext) {
    (my $prot, my $hits, $protNext) = Hits::readHitsManyProts_OnTheFly($fhi, $header, $protNext);
    # make ordered list of accessions that defines this architecture, but keep it as text so we can use it as hash key
    my $arch = '';
    foreach my $h (@$hits) {
	my $acc = $h->{acc}; # get accession
	$acc =~ s/^PF//; # remove PF from intro
	$arch .= $acc.'-'; # add to list, with a dash as separator
    }
    $arch =~ s/-$//; # remove last dash
    # lastly, increase counts for this architecture
    $arch2c{$arch}++;
}
close $fhi;

# done, print the arch and count table
General::printHashFile($FilePaths::pfamArchesExact, \%arch2c, $comp);
