# Copyright (C) 2010 Alejandro Ochoa, Singh Research Group, Princeton University
# This file is part of dPUC.
# dPUC is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
# dPUC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with dPUC.  If not, see <http://www.gnu.org/licenses/>.

use lib '.';
use General;
use FilePaths;
use strict;

# gets the most useful PFAM clans data from this complicated file and stores it into hashes that we can easily access when we need them
# this sub saves the hashes into tab-delimited text files.

# define hash structures
my %famacc2acc; # maps individual families to their clan accession

# a temporary variable that holds the current accession, so everything else can be mapped
my $acc = ''; # current clan accession

# read file
my $fhi = General::getInFh($FilePaths::pfamC);
while(<$fhi>) {
    my ($type, $s);  # things we're parsing for...
    next unless ($type, $s) = /^(\w{2})\s+(.+)$/; # some lines (only '//'?) are not interesting
    if ($type eq 'AC') {
	# read in new accession and process
	$acc = $s;
	$acc =~ s/\.\d+$//; # remove version number
    }
    elsif ($type eq 'MB') {
	# don't store blank entries (keep in mind there are multiple MB lines!)
	# now store what we actually have in this line
	$s =~ s/;$//; # remove final colon.  These family accessions don't have version numbers
	$famacc2acc{$s} = $acc; # map this family accession to its clan
    }
}
close $fhi;

# now save hashes into files
General::printHashFile($FilePaths::pfamClans, \%famacc2acc, 'gzip');
